﻿Type=Class
Version=3.2
@EndOfDesignText@
#Region Class Attributes
'Fired by long press on view
#Event: LongClick
#End Region

Sub Class_Globals
	'Parent that receive events
	Private mEventObject As Object
	'Root name of sub that receive events. Called sub will be : EventName_xxx
	Private mEventRoot As String

	'Gesture detector
	Private mGest As GestureDetector
	'List of current active gesture
	Private mGestList As List
	
	'Base panel
	Private mPnlBase As Panel
	'Panel that receive gesture
	Private mPnlGest As Panel

	Private mPrefScreen As PreferenceScreen
	Private mPrefManager As PreferenceManager
	
	Private mFFTLength As Int
End Sub

'Initialise la classe
'CallbackModule : Objet auquel seront transmis les evenements.
'EventName : Racine du nom des sub recevant les evenements. Le sub appelees se nommerons EventName_xxx.
'PnlToDraw : Panel dans lequel sera dessiné le spectre
Public Sub Initialize(CallbackModule As Object, EventName As String, PnlToDraw As Panel)
	mEventObject = CallbackModule
	mEventRoot = EventName
	mPnlBase = PnlToDraw
	'Initialisation du panel des curseurs
	mPnlGest.Initialize("mPnlGest")
	mPnlBase.AddView(mPnlGest, 0, 0, mPnlBase.Width, mPnlBase.Height)
	'Initialise le detecteur de gestes
	mGest.SetOnGestureListener(mPnlGest, "mGest")
	mGestList.Initialize
	'Initialise les preferences
	ReadAllPreferences
	mPrefScreen.Initialize("Test Gesture Preferences", "Test Gesture Preferences")
	FillMnuPref
End Sub

'Return preferences screen
Public Sub getPreferenceScreen As PreferenceScreen
	Return mPrefScreen
End Sub

'Read and apply all preferences
Public Sub ReadAllPreferences
	Dim AllPref As Map = mPrefManager.GetAll	'Ensemble des preferences
	Dim ValStr As String	'Chaine de lecture
	'Lecture des preferences
	'Longueur FFT
	ValStr = AllPref.get("TestGest_FFTLength")
	If IsNumber(ValStr) Then mFFTLength = ValStr
End Sub

'Fill all preferences menu
Private Sub FillMnuPref
	FillMnuFFTLengths
End Sub

'Fill FFT length preference menu
Private Sub FillMnuFFTLengths()
	Dim Lst As List : Lst.Initialize
	Dim Cpt As Int
	Dim Val As Int
	For Cpt =  7 To 14
		Val = Power(2.0, Cpt)
		Lst.Add(Val)
	Next
	mPrefScreen.AddList("TestGest_FFTLength", "FFT Length", "Number of data point use for FFT calculation.", mFFTLength, Lst)
End Sub

'Event receive for first contact
Private Sub mGest_onDown(X As Float, Y As Float, MotionEvent As Object)
	'Ajoute le premier cuseur a la liste
	mGest_onPointerDown(0, 0, MotionEvent)
End Sub

'Event receive for conatct after first one
Private Sub mGest_onPointerDown(ptrIndex As Int, PID As Int, MotionEvent As Object)
	'Add pointer to the list
	mGestList.InsertAt(ptrIndex, -1)
End Sub

'Event receive on motion or living last contact
Private Sub mGest_onTouch(Action As Int, X As Float, Y As Float, MotionEvent As Object) As Boolean
	If Action = mGest.ACTION_UP Then
		mGest_onPointerUp(0, 0, MotionEvent)
	End If
	Return True
End Sub

'Evenement indiquant un relachement d'un doigt
Private Sub mGest_onPointerUp(ptrIndex As Int, PID As Int, MotionEvent As Object)
	'Removes this painter from the list
	Dim Id As Int = mGestList.get(ptrIndex)
	mGestList.RemoveAt(ptrIndex)
End Sub

'Evenement indiquant un appui long
Private Sub mGest_onLongPress(X As Float, Y As Float, MotionEvent As Object)
	SendEvt("LongClick")
End Sub

'Fire event without parameter
Private Sub SendEvt(EvtName As String)
	'Declenche l'evenement si on est abonne
	If (mEventObject = Null) OR (mEventRoot.Length = 0) Then Return
	If SubExists(mEventObject , mEventRoot & "_" & EvtName) Then CallSub(mEventObject, mEventRoot & "_" & EvtName)
End Sub

